@@ -33,9 +33,15 @@ class IMP_Ajax_Application_Handler_ImageUnblock extends Horde_Core_Ajax_Applicat
     {
         global $injector, $notification;
 
-        $address = $injector->getInstance('IMP_Factory_Contents')->create(new IMP_Indices_Mailbox($this->vars))->getHeader()->getOb('from')->bare_addresses[0];
+        $indices = new IMP_Indices_Mailbox($this->vars);
+        $address = $injector->getInstance('IMP_Factory_Contents')
+            ->create($indices)
+            ->getHeader()
+            ->getOb('from')
+            ->bare_addresses[0];
 
         if ($injector->getInstance('IMP_Prefs_Special_ImageReplacement')->addSafeAddrList($address)) {
+            $this->_base->queue->message($indices);
             $notification->push(sprintf(_("Always showing images in messages sent by %s."), $address), 'horde.success');
         }
 
