@@ -41,8 +41,9 @@ class IMP_Ajax_Imple_ItipRequest extends Horde_Core_Ajax_Imple
     protected function _attach($init)
     {
         return array(
+            'ctype' => $this->_params['ctype'],
             'mime_id' => $this->_params['mime_id'],
-            'muid' => $this->_params['muid']
+            'muid' => $this->_params['muid'],
         );
     }
 
@@ -69,7 +70,12 @@ class IMP_Ajax_Imple_ItipRequest extends Horde_Core_Ajax_Imple
             $mime_part = $contents->getMIMEPart($vars->mime_id);
             if (empty($mime_part)) {
                 throw new IMP_Exception(_("Cannot retrieve calendar data from message."));
-            } elseif (!$vCal->parsevCalendar($mime_part->getContents(), 'VCALENDAR', $mime_part->getCharset())) {
+            }
+            if ($vars->ctype) {
+                $mime_part = clone $mime_part;
+                $mime_part->setType($vars->ctype);
+            }
+            if (!$vCal->parsevCalendar($mime_part->getContents(), 'VCALENDAR', $mime_part->getCharset())) {
                 throw new IMP_Exception(_("The calendar data is invalid"));
             }
 
@@ -154,8 +160,8 @@ class IMP_Ajax_Imple_ItipRequest extends Horde_Core_Ajax_Imple
                             }
                         } catch (Horde_Icalendar_Exception $e) {}
                     }
-
                     break;
+
                 case 'vFreebusy':
                     // Import into Kronolith.
                     if ($registry->hasMethod('calendar/import_vfreebusy')) {
@@ -440,6 +446,7 @@ class IMP_Ajax_Imple_ItipRequest extends Horde_Core_Ajax_Imple
 
             } catch (Horde_Exception $e) {
                 $notification->push(sprintf(_("There was an error importing the event: %s"), $e->getMessage()), 'horde.error');
+                return false;
             }
         }
 
