@@ -296,10 +296,10 @@ class IMP_Basic_Folders extends IMP_Basic_Base
                 $sum = 0;
 
                 foreach ($mbox_list as $val) {
-                    $size = $val->size;
+                    $size = $val->size_raw;
                     $data = array(
                         'name' => $val->display,
-                        'size' => sprintf(_("%.2fMB"), $size / (1024 * 1024)),
+                        'size' => $val->size,
                         'sort' => $size
                     );
                     $sum += $size;
@@ -421,7 +421,7 @@ class IMP_Basic_Folders extends IMP_Basic_Base
 
         $displayNames = $fullNames = array();
 
-        foreach ($ftree as $val) {
+        foreach ($iterator as $val) {
             $mbox_ob = $val->mbox_ob;
             $tmp = $displayNames[] = $mbox_ob->display;
 
