@@ -144,7 +144,7 @@ class IMP_Maillog_Storage_History extends IMP_Maillog_Storage_Base
 
     /**
      */
-    public function deleteLogs(array $msgs)
+    public function deleteLogs($msgs)
     {
         $ids = array();
         foreach ($msgs as $val) {
@@ -184,15 +184,17 @@ class IMP_Maillog_Storage_History extends IMP_Maillog_Storage_Base
     /**
      * Generate the unique log ID for an event.
      *
-     * @param mixed $msg  An IMP_Maillog_Message object or, if null, return
-     *                    the parent ID.
+     * @param mixed $msg  An IMP_Maillog_Message object, a Message-ID, or, if
+     *                    null, return the parent ID.
      *
      * @return string  The unique log ID.
      * @throws RuntimeException
      */
     protected function _getUniqueHistoryId($msg = null)
     {
-        $msgid = $msg ? $msg->msgid : null;
+        $msgid = $msg
+            ? (is_string($msg) ? $msg : $msg->msgid)
+            : null;
         if ($msgid === '') {
             throw new RuntimeException('Message-ID missing.');
         }
