@@ -251,7 +251,9 @@ class IMP_Mime_Viewer_Smime extends Horde_Mime_Viewer_Base
     {
         $partlist = array_keys($this->_mimepart->contentTypeMap());
         $base_id = reset($partlist);
-        $data_id = next($partlist);
+        if (!$data_id = next($partlist)) {
+            $data_id = $base_id;
+        }
         $sig_id = Horde_Mime::mimeIdArithmetic($data_id, 'next');
 
         /* Initialize inline data. */
@@ -270,16 +272,6 @@ class IMP_Mime_Viewer_Smime extends Horde_Mime_Viewer_Base
             return null;
         }
 
-        /* Sanity checking to make sure MIME structure is correct. */
-        if (!in_array($sig_id, $partlist)) {
-            $status->action(IMP_Mime_Status::ERROR);
-            $cache->smime[$base_id]['wrap'] = 'mimePartWrapInvalid';
-            $status->addText(_("Invalid S/MIME data."));
-            /* This will suppress displaying the invalid part. */
-            $cache->smime[$base_id]['sig'] = $data_id;
-            return null;
-        }
-
         $imp_contents = $this->getConfigParam('imp_contents');
         $stream = $imp_contents->isEmbedded($base_id)
             ? $this->_mimepart->getMetadata('imp-smime-decrypt')->stream
